.. module:: enaml.widgets.file_dialog

=========================
enaml.widgets.file_dialog
=========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    FileDialog


.. autoclass:: FileDialog
